package com.factory.controller.web;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.factory.base.entity.aggregates.PageBean;
import com.factory.base.entity.aggregates.ResponseBean;
import com.factory.base.util.res.ResponseBeanBuilder;
import com.factory.web.entity.pm.OnsiteApprovalPlan;
import com.factory.web.entity.pm.OnsiteCalendar;
import com.factory.web.entity.pm.OnsiteItem;
import com.factory.web.entity.pm.OnsiteTitleBlob;
import com.factory.web.entity.pm.OnsiteWorkshop;
import com.factory.web.entity.pm.req.AddItemResultReq;
import com.factory.web.entity.pm.req.AddPmPlanReq;
import com.factory.web.entity.pm.req.EditPmPlanReq;
import com.factory.web.entity.pm.req.PmPlanPauseFlagReq;
import com.factory.web.entity.pm.req.SearchPmItemResultListReq;
import com.factory.web.entity.pm.req.SearchPmPlanListForPadReq;
import com.factory.web.entity.pm.req.SearchPmPlanListReq;
import com.factory.web.entity.pm.req.SearchPmPlanReq;
import com.factory.web.entity.pm.req.SearchTaskReq;
import com.factory.web.entity.pm.req.SearchWorkshopReq;
import com.factory.web.entity.pm.res.PmItemResultListRes;
import com.factory.web.entity.pm.res.PmPlanListForPadRes;
import com.factory.web.entity.pm.res.PmPlanListRes;
import com.factory.web.entity.pm.res.PmPlanRes;
import com.factory.web.service.pm.PreventMistakeService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiOperationSupport;
import lombok.extern.slf4j.Slf4j;

/**
 * 防错计划
 *
 * @author wzy
 * @date 2021-07-09 12:00:00
 */
@Api(tags = "WEB - 防错")
@RestController
@RequestMapping("/benteler/pm")
@Slf4j
public class PreventMistakeController {
	@Autowired
	private PreventMistakeService preventMistakeService;

	@ApiOperation(value = "新建防错计划")
	@PostMapping("/addPmPlan")
	@ApiOperationSupport(order = 1)
	public ResponseBean addPmPlan(@RequestBody AddPmPlanReq req) {
		return ResponseBeanBuilder.ok(preventMistakeService.addPmPlan(req));
	}

	@ApiOperation(value = "取得Web端防错计划列表")
	@ApiOperationSupport(order = 2)
	@PostMapping("/getPmPlanlist")
	public ResponseBean<PageBean<PmPlanListRes>> getPmPlanlist(@RequestBody SearchPmPlanListReq req) {
		return preventMistakeService.getPmPlanList(req);
	}
	
	@ApiOperation(value = "取得防错计划信息")
	@ApiOperationSupport(order = 3)
	@PostMapping("/getPmPlan")
	public ResponseBean<PmPlanRes> getPmPlan(@RequestBody SearchPmPlanReq req) {
		PmPlanRes pmPlanRes = preventMistakeService.getPmPlan(req);
		return ResponseBeanBuilder.ok(pmPlanRes);
	}

	@ApiOperation(value = "禁用防错计划")
	@PostMapping("/disablePmPlan")
	@ApiOperationSupport(order = 4)
	public ResponseBean disablePmPlan(@RequestBody PmPlanPauseFlagReq req) {
		return preventMistakeService.disablePmPlan(req);
	}
	
	@ApiOperation(value = "取得工作站及站下巡检项目信息")
	@ApiOperationSupport(order = 5)
	@PostMapping("/getWorkshop")
	public ResponseBean<OnsiteWorkshop> getWorkshop(@RequestBody SearchWorkshopReq req) {
		return preventMistakeService.getWorkshop(req);
	}
	
	@ApiOperation(value = "修改防错计划")
	@PostMapping("/editPmPlan")
	@ApiOperationSupport(order = 6)
	public ResponseBean editPmPlan(@RequestBody EditPmPlanReq req) {
		return ResponseBeanBuilder.ok(preventMistakeService.editPmPlan(req));
	}

	@ApiOperation(value = "取得计划审批信息")
	@ApiOperationSupport(order = 7)
	@PostMapping("/getPmPlanApprovalList")
	public ResponseBean<List<OnsiteApprovalPlan>> getPmPlanApprovalList(@RequestBody SearchPmPlanReq req) {
		return preventMistakeService.getPmPlanApprovalList(req);
	}
	
	@ApiOperation(value = "取得每频次检查信息")
	@ApiOperationSupport(order = 8)
	@PostMapping("/getCalendarList")
	public ResponseBean<List<OnsiteCalendar>> getCalendarList(@RequestBody SearchPmPlanReq req) {
		return preventMistakeService.getCalendarList(req);
	}
	
	@ApiOperation(value = "检查记录列表")
	@ApiOperationSupport(order = 9)
	@PostMapping("/getPmItemResultList")
	public ResponseBean<List<PmItemResultListRes>> getPmItemResultList(@RequestBody SearchPmItemResultListReq req) {
		return preventMistakeService.getPmItemResultList(req);
	}
	
	@ApiOperation(value = "取得Pad端防错计划列表")
	@ApiOperationSupport(order = 10)
	@PostMapping("/getPmPlanListForPad")
	public ResponseBean<List<PmPlanListForPadRes>> getPmPlanListForPad(@RequestBody SearchPmPlanListForPadReq req) {
		return preventMistakeService.getPmPlanListForPad(req);
	}
	
	@ApiOperation(value = "通过计划ID取得表头")
	@ApiOperationSupport(order = 11)
	@PostMapping("/getTitle")
	public ResponseBean<OnsiteTitleBlob> getTitle(@RequestBody SearchPmPlanReq req) {
		return preventMistakeService.getTitle(req);
	}
	
	@ApiOperation(value = "通过计划ID取得工作站列表")
	@ApiOperationSupport(order = 12)
	@PostMapping("/getWorkshopList")
	public ResponseBean<List<OnsiteWorkshop>> getWorkshopList(@RequestBody SearchPmPlanReq req) {
		return preventMistakeService.getWorkshopList(req);
	}
	
	@ApiOperation(value = "通过工作站ID取得巡检项目列表")
	@ApiOperationSupport(order = 13)
	@PostMapping("/getItemList")
	public ResponseBean<List<OnsiteItem>> getItemList(@RequestBody SearchWorkshopReq req) {
		return preventMistakeService.getItemList(req);
	}
	
	@ApiOperation(value = "添加巡检项目检查结果")
	@PostMapping("/addItemResult")
	@ApiOperationSupport(order = 14)
	public ResponseBean addItemResult(@RequestBody AddItemResultReq req) {
		return ResponseBeanBuilder.ok(preventMistakeService.addItemResult(req));
	}
	
	@ApiOperation(value = "任务检查完后提交")
	@PostMapping("/submitTask")
	@ApiOperationSupport(order = 15)
	public ResponseBean submitTask(@RequestBody SearchTaskReq req) {
		return ResponseBeanBuilder.ok(preventMistakeService.submitTask(req));
	}
	
	// 计划审批、任务审批，都在小程序端做
}
